==> haskell-loch-th-0.2.2-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-loch-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 loch-th
version:              0.2.2
visibility:           public
id:                   loch-th-0.2.2-LskEjTh3FHM4G1PZNDwhMx
key:                  loch-th-0.2.2-LskEjTh3FHM4G1PZNDwhMx
license:              BSD-3-Clause
maintainer:           tomi@nomi.cz
author:               Tomas Janousek
homepage:             https://github.com/liskin/loch-th
synopsis:
    Support for precise error locations in source files (Template Haskell version)

description:
    This module provides a Template Haskell based mechanism to
    tag failures with the location of the failure call. The
    location message includes the file name, line and column
    numbers.

category:             Development
abi:                  b51f074c9d3fe73dd133b88c1f19c1bc
exposed:              True
exposed-modules:      Debug.Trace.LocationTH
import-dirs:          /usr/lib/ghc-9.0.1/site-local/loch-th-0.2.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/loch-th-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/loch-th-0.2.2
hs-libraries:         HSloch-th-0.2.2-LskEjTh3FHM4G1PZNDwhMx
depends:
    base-4.15.0.0 pretty-1.1.3.6 template-haskell-2.17.0.0

haddock-interfaces:   /usr/share/doc/haskell-loch-th/html/loch-th.haddock
haddock-html:         /usr/share/doc/haskell-loch-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loch-th-0.2.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-loch-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 loch-th
version:              0.2.2
visibility:           public
id:                   loch-th-0.2.2-B97TDiGPvnFDi2zc99r9Fy
key:                  loch-th-0.2.2-B97TDiGPvnFDi2zc99r9Fy
license:              BSD-3-Clause
maintainer:           tomi@nomi.cz
author:               Tomas Janousek
homepage:             https://github.com/liskin/loch-th
synopsis:
    Support for precise error locations in source files (Template Haskell version)

description:
    This module provides a Template Haskell based mechanism to
    tag failures with the location of the failure call. The
    location message includes the file name, line and column
    numbers.

category:             Development
abi:                  98b86ff7d832374c8e2d5f98ca7a3b30
exposed:              True
exposed-modules:      Debug.Trace.LocationTH
import-dirs:          /usr/lib/ghc-9.0.2/site-local/loch-th-0.2.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/loch-th-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/loch-th-0.2.2
hs-libraries:         HSloch-th-0.2.2-B97TDiGPvnFDi2zc99r9Fy
depends:
    base-4.15.1.0 pretty-1.1.3.6 template-haskell-2.17.0.0

haddock-interfaces:   /usr/share/doc/haskell-loch-th/html/loch-th.haddock
haddock-html:         /usr/share/doc/haskell-loch-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
